/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                      **** FORMACIN CVICA Y TICA ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE FORMACIN
/*                        CVICA Y TICA EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Alum_FCE.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Alum_FCE.txt
/*         as como el archivo Excale09_2008_Alum_FCE.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Alum_FCE.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Alum_FCE.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale09_2008_Alum_FCE.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $mageb05f   "R"       ="Escuela rural"
                       "UA"      ="Escuela urbana de alta marginacin"
                       "UB"      ="Escuela urbana de baja marginacin"
                       "NA"      ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="14 aos o menos"
                       2         ="15 aos"
                       3         ="16 aos"
                       4         ="17 aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ca1_e23F    0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale09_2008_Alum_FCE;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       alumno             6
       id_instr           $16
       sexo               3
       edad               8
       edadc              3
       edadn              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       sca_01             3
       sca_02             3
       sca_03             3
       sca_04             3
       sca_05             3
       sca_06             3
       sca_07             3
       sca_08             3
       sca_09             3
       sca_10             3
       sca_11             3
       sca_12             3
       sca_13             3
       sca_14             3
       sca_15             3
       sca_16             3
       sca_17             3
       sca_18             3
       sca_19             3
       sca_20             3
       sca_21             3
       sca_22             3
       sca_23             3
       scb_01             3
       scb_02             3
       scb_03             3
       scb_04             3
       scb_05             3
       scb_06             3
       scb_07             3
       scb_08             3
       scb_09             3
       scb_10             3
       scb_11             3
       scb_12             3
       scb_13             3
       scb_14             3
       scb_15             3
       scb_16             3
       scb_17             3
       scb_18             3
       scb_19             3
       scb_20             3
       scb_21             3
       scb_22             3
       scb_23             3
       scc_01             3
       scc_02             3
       scc_03             3
       scc_04             3
       scc_05             3
       scc_06             3
       scc_07             3
       scc_08             3
       scc_09             3
       scc_10             3
       scc_11             3
       scc_12             3
       scc_13             3
       scc_14             3
       scc_15             3
       scc_16             3
       scc_17             3
       scc_18             3
       scc_19             3
       scc_20             3
       scc_21             3
       scc_22             3
       scc_23             3
       scd_01             3
       scd_02             3
       scd_03             3
       scd_04             3
       scd_05             3
       scd_06             3
       scd_07             3
       scd_08             3
       scd_09             3
       scd_10             3
       scd_11             3
       scd_12             3
       scd_13             3
       scd_14             3
       scd_15             3
       scd_16             3
       scd_17             3
       scd_18             3
       scd_19             3
       scd_20             3
       scd_21             3
       scd_22             3
       scd_23             3
       sce_01             3
       sce_02             3
       sce_03             3
       sce_04             3
       sce_05             3
       sce_06             3
       sce_07             3
       sce_08             3
       sce_09             3
       sce_10             3
       sce_11             3
       sce_12             3
       sce_13             3
       sce_14             3
       sce_15             3
       sce_16             3
       sce_17             3
       sce_18             3
       sce_19             3
       sce_20             3
       sce_21             3
       sce_22             3
       sce_23             3
       pv1civ             8
       pv2civ             8
       pv3civ             8
       pv4civ             8
       pv5civ             8
       civnvl1            3
       civnvl2            3
       civnvl3            3
       civnvl4            3
       civnvl5            3
       civnvlb1           3
       civnvlb2           3
       civnvlb3           3
       civnvlb4           3
       civnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1149;
   INPUT
       nacional            1 - 1
       escuela             2 - 5
       id_ent              6 - 7
       nom_ent             8 - 26
       id_mod             27 - 27
       mod                28 - 31
       mageb05            32 - 33
       estrato            34 - 40
       entest             41 - 46
       alumno             47 - 52
       id_instr           53 - 68
       sexo               69 - 69
       edad               70 - 80
       edadc              81 - 81
       edadn              82 - 82
       edad_ac            83 - 84
       mes_nac            85 - 86
       w_alu              87 - 97
       docente            98 - 102
       sca_01            103 - 103
       sca_02            104 - 104
       sca_03            105 - 105
       sca_04            106 - 106
       sca_05            107 - 107
       sca_06            108 - 108
       sca_07            109 - 109
       sca_08            110 - 110
       sca_09            111 - 111
       sca_10            112 - 112
       sca_11            113 - 113
       sca_12            114 - 114
       sca_13            115 - 115
       sca_14            116 - 116
       sca_15            117 - 117
       sca_16            118 - 118
       sca_17            119 - 119
       sca_18            120 - 120
       sca_19            121 - 121
       sca_20            122 - 122
       sca_21            123 - 123
       sca_22            124 - 124
       sca_23            125 - 125
       scb_01            126 - 126
       scb_02            127 - 127
       scb_03            128 - 128
       scb_04            129 - 129
       scb_05            130 - 130
       scb_06            131 - 131
       scb_07            132 - 132
       scb_08            133 - 133
       scb_09            134 - 134
       scb_10            135 - 135
       scb_11            136 - 136
       scb_12            137 - 137
       scb_13            138 - 138
       scb_14            139 - 139
       scb_15            140 - 140
       scb_16            141 - 141
       scb_17            142 - 142
       scb_18            143 - 143
       scb_19            144 - 144
       scb_20            145 - 145
       scb_21            146 - 146
       scb_22            147 - 147
       scb_23            148 - 148
       scc_01            149 - 149
       scc_02            150 - 150
       scc_03            151 - 151
       scc_04            152 - 152
       scc_05            153 - 153
       scc_06            154 - 154
       scc_07            155 - 155
       scc_08            156 - 156
       scc_09            157 - 157
       scc_10            158 - 158
       scc_11            159 - 159
       scc_12            160 - 160
       scc_13            161 - 161
       scc_14            162 - 162
       scc_15            163 - 163
       scc_16            164 - 164
       scc_17            165 - 165
       scc_18            166 - 166
       scc_19            167 - 167
       scc_20            168 - 168
       scc_21            169 - 169
       scc_22            170 - 170
       scc_23            171 - 171
       scd_01            172 - 172
       scd_02            173 - 173
       scd_03            174 - 174
       scd_04            175 - 175
       scd_05            176 - 176
       scd_06            177 - 177
       scd_07            178 - 178
       scd_08            179 - 179
       scd_09            180 - 180
       scd_10            181 - 181
       scd_11            182 - 182
       scd_12            183 - 183
       scd_13            184 - 184
       scd_14            185 - 185
       scd_15            186 - 186
       scd_16            187 - 187
       scd_17            188 - 188
       scd_18            189 - 189
       scd_19            190 - 190
       scd_20            191 - 191
       scd_21            192 - 192
       scd_22            193 - 193
       scd_23            194 - 194
       sce_01            195 - 195
       sce_02            196 - 196
       sce_03            197 - 197
       sce_04            198 - 198
       sce_05            199 - 199
       sce_06            200 - 200
       sce_07            201 - 201
       sce_08            202 - 202
       sce_09            203 - 203
       sce_10            204 - 204
       sce_11            205 - 205
       sce_12            206 - 206
       sce_13            207 - 207
       sce_14            208 - 208
       sce_15            209 - 209
       sce_16            210 - 210
       sce_17            211 - 211
       sce_18            212 - 212
       sce_19            213 - 213
       sce_20            214 - 214
       sce_21            215 - 215
       sce_22            216 - 216
       sce_23            217 - 217
       pv1civ            218 - 225
       pv2civ            226 - 233
       pv3civ            234 - 241
       pv4civ            242 - 249
       pv5civ            250 - 257
       civnvl1           258 - 258
       civnvl2           259 - 259
       civnvl3           260 - 260
       civnvl4           261 - 261
       civnvl5           262 - 262
       civnvlb1          263 - 263
       civnvlb2          264 - 264
       civnvlb3          265 - 265
       civnvlb4          266 - 266
       civnvlb5          267 - 267
       wvarstrr          268 - 269
       w_fstr1           270 - 280
       w_fstr2           281 - 291
       w_fstr3           292 - 302
       w_fstr4           303 - 313
       w_fstr5           314 - 324
       w_fstr6           325 - 335
       w_fstr7           336 - 346
       w_fstr8           347 - 357
       w_fstr9           358 - 368
       w_fstr10          369 - 379
       w_fstr11          380 - 390
       w_fstr12          391 - 401
       w_fstr13          402 - 412
       w_fstr14          413 - 423
       w_fstr15          424 - 434
       w_fstr16          435 - 445
       w_fstr17          446 - 456
       w_fstr18          457 - 467
       w_fstr19          468 - 478
       w_fstr20          479 - 489
       w_fstr21          490 - 500
       w_fstr22          501 - 511
       w_fstr23          512 - 522
       w_fstr24          523 - 533
       w_fstr25          534 - 544
       w_fstr26          545 - 555
       w_fstr27          556 - 566
       w_fstr28          567 - 577
       w_fstr29          578 - 588
       w_fstr30          589 - 599
       w_fstr31          600 - 610
       w_fstr32          611 - 621
       w_fstr33          622 - 632
       w_fstr34          633 - 643
       w_fstr35          644 - 654
       w_fstr36          655 - 665
       w_fstr37          666 - 676
       w_fstr38          677 - 687
       w_fstr39          688 - 698
       w_fstr40          699 - 709
       w_fstr41          710 - 720
       w_fstr42          721 - 731
       w_fstr43          732 - 742
       w_fstr44          743 - 753
       w_fstr45          754 - 764
       w_fstr46          765 - 775
       w_fstr47          776 - 786
       w_fstr48          787 - 797
       w_fstr49          798 - 808
       w_fstr50          809 - 819
       w_fstr51          820 - 830
       w_fstr52          831 - 841
       w_fstr53          842 - 852
       w_fstr54          853 - 863
       w_fstr55          864 - 874
       w_fstr56          875 - 885
       w_fstr57          886 - 896
       w_fstr58          897 - 907
       w_fstr59          908 - 918
       w_fstr60          919 - 929
       w_fstr61          930 - 940
       w_fstr62          941 - 951
       w_fstr63          952 - 962
       w_fstr64          963 - 973
       w_fstr65          974 - 984
       w_fstr66          985 - 995
       w_fstr67          996 - 1006
       w_fstr68         1007 - 1017
       w_fstr69         1018 - 1028
       w_fstr70         1029 - 1039
       w_fstr71         1040 - 1050
       w_fstr72         1051 - 1061
       w_fstr73         1062 - 1072
       w_fstr74         1073 - 1083
       w_fstr75         1084 - 1094
       w_fstr76         1095 - 1105
       w_fstr77         1106 - 1116
       w_fstr78         1117 - 1127
       w_fstr79         1128 - 1138
       w_fstr80         1139 - 1149
 ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       edad        = "Edad del alumno al mes de mayo de 2008, en aos (al momento de la aplicacin)"
       edadc       = "Edad del alumno al mes de mayo de 2008, codificada (al momento de la aplicacin)"
       edadn       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       sca_01      = "Reconocer la importancia de la Formacin cvica y tica"
       sca_02      = "Determinar los efectos del ejercicio de la libertad"
       sca_03      = "Reconocer la consolidacin de la historia humana"
       sca_04      = "Reconocer la importancia de escuchar y ser escuchado"
       sca_05      = "Proponer mejoras a los usos de los recursos naturales"
       sca_06      = "Identificar acciones ciudadanas"
       sca_07      = "Reconocer roles asignados a las mujeres"
       sca_08      = "Identificar el papel del enamoramiento, empata y sexualidad"
       sca_09      = "Identificar efectos de la maternidad y paternidad precoces"
       sca_10      = "Reconocer rasgos de la explotacin infantil"
       sca_11      = "Identificar valores para las relaciones sociales: solidaridad"
       sca_12      = "Identificar tipos de familia"
       sca_13      = "Identificar tipos de violencia intrafamiliar"
       sca_14      = "Identificar caractersticas del ciclo vital de la familia"
       sca_15      = "Identificar condiciones de compaerismo y amistad"
       sca_16      = "Identificar necesidades educativas en la secundaria"
       sca_17      = "Reconocer la diferencia entre pas y nacin"
       sca_18      = "Excluir de estimacin de puntajes"
       sca_19      = "Reconocer las responsabilidades generacionales"
       sca_20      = "Identificar abusos en el ejercicio de la autoridad"
       sca_21      = "Excluir de estimacin de puntajes"
       sca_22      = "Identificar significados de la palabra democracia"
       sca_23      = "Reconocer disensos y consensos en la pluralidad"
       scb_01      = "Identificar patrimonios personales"
       scb_02      = "Identificar usos del potencial creativo"
       scb_03      = "Identificar acciones personales y sociales con intencin poltica"
       scb_04      = "Reconocer al gnero como construccin social"
       scb_05      = "Reconocer consecuencias de la adiccin en el sujeto"
       scb_06      = "Reconocer el trfico de drogas como problema de salud pblico"
       scb_07      = "Identificar a los medios de comunicacin en la prevencin de adicciones"
       scb_08      = "Reconocer las ventajas de hacer proyectos de vida en la juventud"
       scb_09      = "Identificar el propsito de estudiar para trabajar"
       scb_10      = "Reconocer la dignificacin del ser humano a travs del trabajo"
       scb_11      = "Identificar  las relaciones entre intereses, oportunidades de formacin y trabajo"
       scb_12      = "Reconocer al valor como motor en la transformacin social"
       scb_13      = "Identificar derechos de los miembros de la familia"
       scb_14      = "Identificar acciones y valores para un buen ambiente familiar"
       scb_15      = "Reconocer el sentido de las relaciones afectivas en la vida"
       scb_16      = "Identificar caractersticas de una sociedad cohesionada"
       scb_17      = "Reconocer las garantas individuales en la Constitucin"
       scb_18      = "Relacionar las garantas individuales con los derechos humanos"
       scb_19      = "Reconocer a Mxico como repblica, representativa, democrtica y federal"
       scb_20      = "Identificar valores en la democracia"
       scb_21      = "Identificar las relaciones entre valores y leyes"
       scb_22      = "Reconocer instituciones democrticas que delimitan el poder"
       scb_23      = "Reconocer la importancia del dilogo y los acuerdos en sociedades democrticas"
       scc_01      = "Reconocer el uso irresponsable de los recursos naturales"
       scc_02      = "Identificar elementos que nos hacen diferentes entre s"
       scc_03      = "Reconocer diferencias y semejanzas en la vida social"
       scc_04      = "Identificar actores involucrados en los artculos 3o y 31 de la Constitucin"
       scc_05      = "Identificar estereotipos en los medios de comunicacin"
       scc_06      = "Identificar ventajas del ejercicio de la sexualidad de manera responsable"
       scc_07      = "Reconocer a la salud como bienestar fsico, mental y social"
       scc_08      = "Identificar el concepto de droga"
       scc_09      = "Reconocer necesidades, intereses y motivaciones en el proyecto de vida"
       scc_10      = "Reconocer al trabajo como medio de realizacin personal"
       scc_11      = "Diferenciar finalidades para organizarse socialmente"
       scc_12      = "Reconocer normas para la vida en sociedad"
       scc_13      = "Identificar transformaciones histricas de las prcticas sociales"
       scc_14      = "Reconocer la funcin de la familia"
       scc_15      = "Identificar los elementos del Estado"
       scc_16      = "Identificar la nocin de soberana"
       scc_17      = "Reconocer la importancia de la divisin de poderes en Mxico"
       scc_18      = "Excluir de estimacin de puntajes"
       scc_19      = "Reconocer la influencia de la participacin ciudadana en asuntos pblicos"
       scc_20      = "Identificar beneficios de la organizacin social democrtica"
       scc_21      = "Reconocer criterios de eleccin democrticos"
       scc_22      = "Identificar el ejercicio democrtico del poder en organizaciones sociales"
       scc_23      = "Identificar formas de participacin para la construccin de sociedades democrticas"
       scd_01      = "Identificar voluntad, eleccin y reconocimiento como aspectos de la libertad"
       scd_02      = "Identificar al trabajo como expresin creativa y transformadora"
       scd_03      = "Reconocer a la sexualidad como bio-psico-social"
       scd_04      = "Reconocer derechos y obligaciones constitucionales de los ciudadanos mexicanos"
       scd_05      = "Identificar al estudio como responsabilidad social"
       scd_06      = "Identificar implicaciones sociales de los cambios en la adolescencia"
       scd_07      = "Identificar riesgos para la salud en prcticas sexuales sin proteccin"
       scd_08      = "Identificar la relacin entre prcticas cotidianas y buena salud"
       scd_09      = "Reconocer conductas de las personas adictas"
       scd_10      = "Identificar prcticas discriminatorias en el mercado laboral"
       scd_11      = "Identificar valores para las relaciones sociales: Libertad"
       scd_12      = "Identificar valores para las relaciones sociales: Respeto"
       scd_13      = "Reconocer al valor como motor en la transformacin cultural"
       scd_14      = "Identificar acciones personales que repercutirn en la humanidad"
       scd_15      = "Reconocer aspectos de la proteccin legal del medio ambiente"
       scd_16      = "Identificar consecuencias de mi forma de vida en el medio ambiente"
       scd_17      = "Identificar la estructura de la Constitucin: Garantas individuales"
       scd_18      = "Identificar derechos laborales"
       scd_19      = "Identificar al juicio de amparo como mecanismo de defensa de derechos"
       scd_20      = "Identificar atribuciones de diferentes autoridades"
       scd_21      = "Reconocer la adquisicin de valores"
       scd_22      = "Identificar valores personales, colectivos y universales"
       scd_23      = "Reconocer la relacin entre mayoras y minoras en la democracia"
       sce_01      = "Excluir de estimacin de puntajes"
       sce_02      = "Reconocer el concepto de ser poltico"
       sce_03      = "Reconocer problemas de la educacin en Mxico"
       sce_04      = "Reconocer ventajas sociales del uso de anticonceptivos"
       sce_05      = "Identificar el concepto de adiccin"
       sce_06      = "Identificar instituciones de apoyo a personas con adicciones"
       sce_07      = "Identificar la promocin del consumo de drogas en los medios de comunicacin"
       sce_08      = "Identificar alcances y consecuencias del proyecto de vida"
       sce_09      = "Identificar elementos en el diseo de un proyecto"
       sce_10      = "Identificar instituciones de proteccin de nios trabajadores"
       sce_11      = "Reconocer la utilidad de establecer relaciones con personas y grupos cercanos"
       sce_12      = "Identificar valores para las relaciones sociales: Tolerancia"
       sce_13      = "Identificar valores para las relaciones sociales: Cooperacin"
       sce_14      = "Identificar a la Democracia"
       sce_15      = "Reconocer acciones que mejoran el equilibrio ambiental"
       sce_16      = "Reconocer la importancia de la Constitucin en la organizacin del pas"
       sce_17      = "Identificar los valores que fundamentan la Constitucin de 1917"
       sce_18      = "Identificar derechos laborales. Artculo 123"
       sce_19      = "Identificar la estructura del poder legislativo"
       sce_20      = "Reconocer las responsabilidades de las autoridades"
       sce_21      = "Identificar el concepto de valor"
       sce_22      = "Reconocer organizaciones sociales democrticas"
       sce_23      = "Identificar caractersticas de la participacin democrtica"
       pv1civ      = "Primer valor plausible de Formacin cvica y tica"
       pv2civ      = "Segundo valor plausible de Formacin cvica y tica"
       pv3civ      = "Tercer valor plausible de Formacin cvica y tica"
       pv4civ      = "Cuarto valor plausible de Formacin cvica y tica"
       pv5civ      = "Quinto valor plausible de Formacin cvica y tica"
       civnvl1     = "Nivel de logro en Formacin cvica y tica. Asociado a PV1CIV. (Cuatro niveles)"
       civnvl2     = "Nivel de logro en Formacin cvica y tica. Asociado a PV2CIV. (Cuatro niveles)"
       civnvl3     = "Nivel de logro en Formacin cvica y tica. Asociado a PV3CIV. (Cuatro niveles)"
       civnvl4     = "Nivel de logro en Formacin cvica y tica. Asociado a PV4CIV. (Cuatro niveles)"
       civnvl5     = "Nivel de logro en Formacin cvica y tica. Asociado a PV5CIV. (Cuatro niveles)"
       civnvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Formacin cvica y tica. Asociado a PV1CIV."
       civnvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Formacin cvica y tica. Asociado a PV2CIV."
       civnvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Formacin cvica y tica. Asociado a PV3CIV."
       civnvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Formacin cvica y tica. Asociado a PV4CIV."
       civnvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Formacin cvica y tica. Asociado a PV5CIV."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       mageb05            mageb05F.
       estrato            $char7.
       entest             $char6.
       alumno             5.
       id_instr           $char16.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       sca_01             ca1_e23F.
       sca_02             ca1_e23F.
       sca_03             ca1_e23F.
       sca_04             ca1_e23F.
       sca_05             ca1_e23F.
       sca_06             ca1_e23F.
       sca_07             ca1_e23F.
       sca_08             ca1_e23F.
       sca_09             ca1_e23F.
       sca_10             ca1_e23F.
       sca_11             ca1_e23F.
       sca_12             ca1_e23F.
       sca_13             ca1_e23F.
       sca_14             ca1_e23F.
       sca_15             ca1_e23F.
       sca_16             ca1_e23F.
       sca_17             ca1_e23F.
       sca_18             ca1_e23F.
       sca_19             ca1_e23F.
       sca_20             ca1_e23F.
       sca_21             ca1_e23F.
       sca_22             ca1_e23F.
       sca_23             ca1_e23F.
       scb_01             ca1_e23F.
       scb_02             ca1_e23F.
       scb_03             ca1_e23F.
       scb_04             ca1_e23F.
       scb_05             ca1_e23F.
       scb_06             ca1_e23F.
       scb_07             ca1_e23F.
       scb_08             ca1_e23F.
       scb_09             ca1_e23F.
       scb_10             ca1_e23F.
       scb_11             ca1_e23F.
       scb_12             ca1_e23F.
       scb_13             ca1_e23F.
       scb_14             ca1_e23F.
       scb_15             ca1_e23F.
       scb_16             ca1_e23F.
       scb_17             ca1_e23F.
       scb_18             ca1_e23F.
       scb_19             ca1_e23F.
       scb_20             ca1_e23F.
       scb_21             ca1_e23F.
       scb_22             ca1_e23F.
       scb_23             ca1_e23F.
       scc_01             ca1_e23F.
       scc_02             ca1_e23F.
       scc_03             ca1_e23F.
       scc_04             ca1_e23F.
       scc_05             ca1_e23F.
       scc_06             ca1_e23F.
       scc_07             ca1_e23F.
       scc_08             ca1_e23F.
       scc_09             ca1_e23F.
       scc_10             ca1_e23F.
       scc_11             ca1_e23F.
       scc_12             ca1_e23F.
       scc_13             ca1_e23F.
       scc_14             ca1_e23F.
       scc_15             ca1_e23F.
       scc_16             ca1_e23F.
       scc_17             ca1_e23F.
       scc_18             ca1_e23F.
       scc_19             ca1_e23F.
       scc_20             ca1_e23F.
       scc_21             ca1_e23F.
       scc_22             ca1_e23F.
       scc_23             ca1_e23F.
       scd_01             ca1_e23F.
       scd_02             ca1_e23F.
       scd_03             ca1_e23F.
       scd_04             ca1_e23F.
       scd_05             ca1_e23F.
       scd_06             ca1_e23F.
       scd_07             ca1_e23F.
       scd_08             ca1_e23F.
       scd_09             ca1_e23F.
       scd_10             ca1_e23F.
       scd_11             ca1_e23F.
       scd_12             ca1_e23F.
       scd_13             ca1_e23F.
       scd_14             ca1_e23F.
       scd_15             ca1_e23F.
       scd_16             ca1_e23F.
       scd_17             ca1_e23F.
       scd_18             ca1_e23F.
       scd_19             ca1_e23F.
       scd_20             ca1_e23F.
       scd_21             ca1_e23F.
       scd_22             ca1_e23F.
       scd_23             ca1_e23F.
       sce_01             ca1_e23F.
       sce_02             ca1_e23F.
       sce_03             ca1_e23F.
       sce_04             ca1_e23F.
       sce_05             ca1_e23F.
       sce_06             ca1_e23F.
       sce_07             ca1_e23F.
       sce_08             ca1_e23F.
       sce_09             ca1_e23F.
       sce_10             ca1_e23F.
       sce_11             ca1_e23F.
       sce_12             ca1_e23F.
       sce_13             ca1_e23F.
       sce_14             ca1_e23F.
       sce_15             ca1_e23F.
       sce_16             ca1_e23F.
       sce_17             ca1_e23F.
       sce_18             ca1_e23F.
       sce_19             ca1_e23F.
       sce_20             ca1_e23F.
       sce_21             ca1_e23F.
       sce_22             ca1_e23F.
       sce_23             ca1_e23F.
       wvarstrr           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(115)
                   sca_01 sca_02 sca_03 sca_04 sca_05 sca_06 sca_07 sca_08 sca_09 sca_10
                   sca_11 sca_12 sca_13 sca_14 sca_15 sca_16 sca_17 sca_18 sca_19 sca_20
                   sca_21 sca_22 sca_23 scb_01 scb_02 scb_03 scb_04 scb_05 scb_06 scb_07
                   scb_08 scb_09 scb_10 scb_11 scb_12 scb_13 scb_14 scb_15 scb_16 scb_17
                   scb_18 scb_19 scb_20 scb_21 scb_22 scb_23 scc_01 scc_02 scc_03 scc_04
                   scc_05 scc_06 scc_07 scc_08 scc_09 scc_10 scc_11 scc_12 scc_13 scc_14
                   scc_15 scc_16 scc_17 scc_18 scc_19 scc_20 scc_21 scc_22 scc_23 scd_01
                   scd_02 scd_03 scd_04 scd_05 scd_06 scd_07 scd_08 scd_09 scd_10 scd_11
                   scd_12 scd_13 scd_14 scd_15 scd_16 scd_17 scd_18 scd_19 scd_20 scd_21
                   scd_22 scd_23 sce_01 sce_02 sce_03 sce_04 sce_05 sce_06 sce_07 sce_08
                   sce_09 sce_10 sce_11 sce_12 sce_13 sce_14 sce_15 sce_16 sce_17 sce_18
                   sce_19 sce_20 sce_21 sce_22 sce_23;
   DO  i=1 TO 115;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
